package t1ck.csv.swfx

import java.text.SimpleDateFormat

import widebase.db.table.Table

/** Filters SWFX data.
 *
 * @author myst3r10n
 */
trait SwfxFilter {

  /** Convert arbitrary timestamps into [[java.lang.Long]] and updates symbol table if necessary.
   *
   * @param symbol the symbol table to update
   * @param timestamp the timestamp format used internal by [[java.text.SimpleDateFormat]]
   *
   * @return filtered data
   */
  def apply(symbol: Table, timestamp: String = "yyyy-MM-dd hh:mm:ss.S") =
    (values: Array[String]) => {

    values(0) =
      (new SimpleDateFormat(timestamp)).parse(values(0)).getTime.toString

    widebase.csv.filter.symbol(symbol, 5)(values)

    values

  }

  /** Convert arbitrary timestamps into [[java.lang.Long]] and updates symbol table if necessary.
   *
   * @param symbol the symbol table to update
   * @param timestamp the timestamp format used internal by [[java.text.SimpleDateFormat]]
   *
   * @return filtered data
   */
  def daily(symbol: Table, timestamp: String = "yyyy-MM-dd hh:mm:ss") =
    (values: Array[String]) => {

    values(0) =
      (new SimpleDateFormat(timestamp)).parse(values(0)).getTime.toString

    widebase.csv.filter.symbol(symbol, 6)(values)

    values

  }
}

